<?php

/*
Plugin Name: Unpublish Post
Description: This plugin allows you to set a date when the post becomes unpublished. Perfect for postings that are only important for a certain time.
Version: 0.1
Author: Benedikt Voigt
*/

// Add a custom meta box to the post type
function fm_add_unpublish_date_meta_box() {
    add_meta_box(
        'fm_unpublish_date',
        __('Unpublish Date', 'fm'),
        'fm_unpublish_date_meta_box_callback',
        'post',
        'side',
        'low'
    );
}

add_action('add_meta_boxes', 'fm_add_unpublish_date_meta_box');

// Callback function to display the meta box
function fm_unpublish_date_meta_box_callback($post) {
    wp_nonce_field('fm_unpublish_date_meta_box', 'fm_unpublish_date_meta_box_nonce');
    $value = get_post_meta($post->ID, '_fm_unpublish_date', true);
    echo '<input type="date" id="fm_unpublish_date" name="fm_unpublish_date" value="' . esc_attr($value) . '">';
}

// Save the meta box data
function fm_save_unpublish_date_meta_box_data($post_id) {
    if (!isset($_POST['fm_unpublish_date_meta_box_nonce'])) {
        return;
    }

    if (!wp_verify_nonce($_POST['fm_unpublish_date_meta_box_nonce'], 'fm_unpublish_date_meta_box')) {
        return;
    }

    $unpublish_date = sanitize_text_field($_POST['fm_unpublish_date']);
    update_post_meta($post_id, '_fm_unpublish_date', $unpublish_date);
}

add_action('save_post', 'fm_save_unpublish_date_meta_box_data');

// Check for posts to unpublish daily
function fm_check_unpublish_posts() {
    $query = new WP_Query(array(
        'meta_key' => '_fm_unpublish_date',
        'meta_value' => date('Y-m-d'),
        'meta_compare' => '<=',
        'post_status' => 'publish',
    ));

    if ($query->have_posts()) {
        while ($query->have_posts()) {
            $query->the_post();
            wp_update_post(array(
                'ID' => get_the_ID(),
                'post_status' => 'draft',
            ));
        }
    }
}

add_action('init', 'fm_check_unpublish_posts');
?>